==> zola-0.15.3.tar.gz: zola-0.15.3/docs/content/themes/serene/index.md <==

+++
title = "serene"
description = "A blog theme for zola, simple and clean."
template = "theme.html"
date = 2022-01-17T03:13:30+08:00

[extra]
created = 2022-01-17T03:13:30+08:00
updated = 2022-01-17T03:13:30+08:00
repository = "https://github.com/isunjn/serene.git"
homepage = "https://github.com/isunjn/serene"
minimum_version = "0.9.0"
license = "MIT"
demo = "https://serene-demo-site.vercel.app"

[extra.author]
name = "isunjn"
homepage = "https://github.com/isunjn"
+++        

English | [简体中文](README-cn.md)

# Serene - A blog theme for zola

Serene is a simple and clean blog theme for Static-Site-Generator [Zola](https://www.getzola.org/).

[Demo](https://serene-demo-site.vercel.app) | [Docs](https://github.com/isunjn/serene/wiki)

## Preview

<details>
  <summary>Click to see screenshots</summary>
  
  ![](screenshots/1.png)
  ![](screenshots/2.png)
  ![](screenshots/3.png)
  ![](screenshots/4.png)
  ![](screenshots/5.png)
  ![](screenshots/6.png)
  ![](screenshots/7.png)
</details>

## Features

- Personal website style
- Simple and clean, focus on content
- Dark mode
- Blog-related features
    - Sticky table-of-contents
    - Image zooming
    - Reading progress bar
    - Admonitions (Info, Important, Warning, etc.)
    - Out-of-date warning
    - Creative-Commons statement
    - Comments
- Web analytics
- Projects page
- Easily customize

## How to use

See [docs](https://github.com/isunjn/serene/wiki).

## Contributing

If you found a bug or want a specific feature, just open an issue.

Be noticed that to keep serene simple, some needs may not be considered. You can implement it in your own site.

## Credits

- [Remixicon](https://remixicon.com/) for icons
- [Lightense Images](https://github.com/sparanoid/lightense-images) for image zooming
- This theme draws some inspiration from these awesome sites:
    - <https://www.zhangxiaochun.com/>
    - <https://lightquantum.me/>
    - <https://theme-cards.ichr.me/>
    - <https://brianlovin.com/>

## License

[MIT](LICENSE)

==> zola-0.16.1.tar.gz: zola-0.16.1/docs/content/themes/serene/index.md <==

+++
title = "serene"
description = "A blog theme for zola, simple and clean."
template = "theme.html"
date = 2022-06-15T01:35:37-07:00

[extra]
created = 2022-06-15T01:35:37-07:00
updated = 2022-06-15T01:35:37-07:00
repository = "https://github.com/isunjn/serene.git"
homepage = "https://github.com/isunjn/serene"
minimum_version = "0.9.0"
license = "MIT"
demo = "https://serene-demo-site.vercel.app"

[extra.author]
name = "isunjn"
homepage = "https://github.com/isunjn"
+++        

English | [简体中文](https://github.com/isunjn/serene/blob/main/README-cn.md)

# Serene - A blog theme for zola

Serene is a simple and clean blog theme for Static-Site-Generator [Zola](https://www.getzola.org/).

[Demo](https://serene-demo-site.vercel.app) | [Docs](https://github.com/isunjn/serene/wiki)

## Preview

<details>
  <summary>Click to see screenshots</summary>
  
  ![](https://github.com/isunjn/serene/blob/main/screenshots/1.png?raw=true)
  ![](https://github.com/isunjn/serene/blob/main/screenshots/2.png?raw=true)
  ![](https://github.com/isunjn/serene/blob/main/screenshots/3.png?raw=true)
  ![](https://github.com/isunjn/serene/blob/main/screenshots/4.png?raw=true)
  ![](https://github.com/isunjn/serene/blob/main/screenshots/5.png?raw=true)
  ![](https://github.com/isunjn/serene/blob/main/screenshots/6.png?raw=true)
  ![](https://github.com/isunjn/serene/blob/main/screenshots/7.png?raw=true)
</details>

## Features

- Personal website style
- Simple and clean, focus on content
- Dark mode
- Blog-related features
    - Sticky table-of-contents
    - Image zooming
    - Reading progress bar
    - Admonitions (Info, Important, Warning, etc.)
    - Out-of-date warning
    - Creative-Commons statement
    - Comments
    - Mathematical notations using [KaTeX](https://katex.org/)
    - Diagrams and visualizations using [Mermaid](https://github.com/mermaid-js/mermaid)
- Web analytics
- Projects page
- Easily customize

## How to use

See [docs](https://github.com/isunjn/serene/wiki).

## Contributing

If you found a bug or want a specific feature, just open an issue.

Be noticed that to keep serene simple, some needs may not be considered. You can implement it in your own site.

## Credits

- [Remixicon](https://remixicon.com/) for icons
- [Lightense Images](https://github.com/sparanoid/lightense-images) for image zooming
- This theme draws some inspiration from these awesome sites:
    - <https://www.zhangxiaochun.com/>
    - <https://lightquantum.me/>
    - <https://theme-cards.ichr.me/>
    - <https://brianlovin.com/>

## License

[MIT](https://github.com/isunjn/serene/blob/main/LICENSE)
